package blatt03;

/**
 * Implementation of the Hamming Distance on Strings.
 * 
 * @author Nils.Hoffmann@CeBiTec.Uni-Bielefeld.DE
 */
public class HammingDistance implements StringDistance{

    /**
     * Computes the Hamming Distance between two Strings.
     * Both need to have the same length, otherwise an Exception
     * of type java.lang.IllegalArgumentException is raised.
     *
     * Strings are used as-is, no lower- or uppercasing is performed!
     *
     * @param a
     * @param b
     * @throws IllegalArgumentException
     * @return
     */
    public double getDistance(String a, String b) throws IllegalArgumentException{
        //check string lengths
        if(a.length()!=b.length()) {
            //raise exception if lengths mismatch
            throw new IllegalArgumentException("String lengths are not equal: "+a.length()+"!="+b.length());
        }
        //largest common index
        int maxindex = Math.min(a.length(),b.length());
        //distance
        int d = 0;
        //loop over strings
        for(int i=0;i<maxindex;i++) {
            //add 0 if a(i)==b(i), 1 else
            d += (a.charAt(i)==b.charAt(i)?0:1);
        }
        //return distance
        return d;
    }

}
